@@ -1,6 +1,6 @@
 use std::fmt::{Debug, Display, Formatter};
 
-/// The Answerer side disconnected and we couldn't ask the question
+/// The Responder side disconnected and we couldn't ask the question
 #[derive(Debug)]
 pub struct AskError<Q> {
     question: Q,
@@ -8,51 +8,51 @@ pub struct AskError<Q> {
 
 /// The Questioner side disconnected and we couldn't answer the question
 #[derive(Debug)]
-pub struct AnswerError<A> {
+pub struct Responderror<A> {
     answer: A,
 }
 
-/// The Answerer side disconnected after the question was asked but before sending an answer
+/// The Responder side disconnected after the question was asked but before sending an answer
 #[derive(Copy, Clone, Debug)]
-pub struct HearError(pub(super)());
+pub struct ListenError(pub(super)());
 
-/// Either the Answerer side disconnected after the question was asked but before sending an answer
+/// Either the Responder side disconnected after the question was asked but before sending an answer
 /// or timed out
 #[derive(Copy, Clone, Debug)]
-pub enum HearTimeoutError {
+pub enum ListenTimeoutError {
     Disconnected,
     Timeout,
 }
 
-/// Either an AskError or a HearError
+/// Either an AskError or a ListenError
 #[derive(Debug)]
 pub enum DialogueError<Q> {
     Ask(AskError<Q>),
-    Hear,
+    Listen,
 }
 
-/// Either an AskError, a HearError or a Timeout
+/// Either an AskError, a ListenError or a Timeout
 #[derive(Debug)]
 pub enum DialogueTimeoutError<Q> {
     Ask(AskError<Q>),
-    Hear,
+    Listen,
     Timeout,
 }
 
 impl<Q> From<DialogueError<Q>> for DialogueTimeoutError<Q> {
     fn from(v: DialogueError<Q>) -> Self {
         match v {
-            DialogueError::Hear => DialogueTimeoutError::Hear,
+            DialogueError::Listen => DialogueTimeoutError::Listen,
             DialogueError::Ask(v) => DialogueTimeoutError::Ask(v),
         }
     }
 }
 
-impl<Q> From<HearTimeoutError> for DialogueTimeoutError<Q> {
-    fn from(v: HearTimeoutError) -> Self {
+impl<Q> From<ListenTimeoutError> for DialogueTimeoutError<Q> {
+    fn from(v: ListenTimeoutError) -> Self {
         match v {
-            HearTimeoutError::Timeout => DialogueTimeoutError::Timeout,
-            HearTimeoutError::Disconnected => DialogueTimeoutError::Hear,
+            ListenTimeoutError::Timeout => DialogueTimeoutError::Timeout,
+            ListenTimeoutError::Disconnected => DialogueTimeoutError::Listen,
         }
     }
 }
@@ -68,7 +68,7 @@ impl<Q> AskError<Q> {
     }
 }
 
-impl<A> AnswerError<A> {
+impl<A> Responderror<A> {
     pub(super) fn new(answer: A) -> Self {
         Self {
             answer
@@ -81,24 +81,24 @@ impl<A> AnswerError<A> {
 
 impl<Q> Display for AskError<Q> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        Display::fmt("Answerer disconnected before question was asked", f)
+        Display::fmt("Responder disconnected before question was asked", f)
     }
 }
-impl<Q> Display for AnswerError<Q> {
+impl<Q> Display for Responderror<Q> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         Display::fmt("Questioner disconnected before answer was sent", f)
     }
 }
-impl Display for HearError {
+impl Display for ListenError {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        Display::fmt("Answerer disconnected before sending an answer", f)
+        Display::fmt("Responder disconnected before sending an answer", f)
     }
 }
-impl Display for HearTimeoutError {
+impl Display for ListenTimeoutError {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
-            HearTimeoutError::Timeout => Display::fmt("Timeout before answer received", f),
-            HearTimeoutError::Disconnected => Display::fmt(&HearError(()), f),
+            ListenTimeoutError::Timeout => Display::fmt("Timeout before answer received", f),
+            ListenTimeoutError::Disconnected => Display::fmt(&ListenError(()), f),
         }
     }
 }
@@ -106,7 +106,7 @@ impl<Q> Display for DialogueError<Q> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             DialogueError::Ask(a) => Display::fmt(a, f),
-            DialogueError::Hear => Display::fmt(&HearError(()), f),
+            DialogueError::Listen => Display::fmt(&ListenError(()), f),
         }
     }
 }
@@ -114,8 +114,8 @@ impl<Q> Display for DialogueTimeoutError<Q> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             DialogueTimeoutError::Ask(a) => Display::fmt(a, f),
-            DialogueTimeoutError::Hear => Display::fmt(&HearError(()), f),
-            DialogueTimeoutError::Timeout => Display::fmt(&HearTimeoutError::Timeout, f),
+            DialogueTimeoutError::Listen => Display::fmt(&ListenError(()), f),
+            DialogueTimeoutError::Timeout => Display::fmt(&ListenTimeoutError::Timeout, f),
         }
     }
 }
\ No newline at end of file
